<?php

namespace Drupal\rdf_sync\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * The RDF sync settings form.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'rdf_sync_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['rdf_sync.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('rdf_sync.settings');

    $form['graph_uri'] = [
      '#type' => 'url',
      '#title' => $this->t('Graph URI'),
      '#default_value' => $config->get('graph_uri') ?? '',
      '#required' => TRUE,
      '#config_target' => 'rdf_sync.settings:graph_uri',
    ];

    $form['endpoint'] = [
      '#type' => 'details',
      '#title' => $this->t('Configure endpoint'),
      '#description' => $this->t('Basic information about RDF endpoint.'),
      '#open' => TRUE,
    ];

    $form['endpoint']['scheme'] = [
      '#type' => 'select',
      '#title' => $this->t('HTTP protocol'),
      '#description' => $this->t('The HTTP protocol to use for sending queries.'),
      '#default_value' => $config->get('endpoint.scheme') ?? 'http',
      '#options' => [
        'http' => $this->t('http'),
        'https' => $this->t('https'),
      ],
      '#config_target' => 'rdf_sync.settings:endpoint.scheme',
    ];

    $form['endpoint']['host'] = [
      '#type' => 'textfield',
      '#title' => $this->t('RDF host'),
      '#description' => $this->t('The host name or IP of your RDF server.'),
      '#default_value' => $config->get('endpoint.host') ?? '',
      '#required' => TRUE,
      '#config_target' => 'rdf_sync.settings:endpoint.host',
    ];

    $form['endpoint']['port'] = [
      '#type' => 'number',
      '#title' => $this->t('RDF port'),
      '#default_value' => $config->get('endpoint.port') ?? '',
      '#required' => TRUE,
      '#min' => 1,
      '#config_target' => 'rdf_sync.settings:endpoint.port',
    ];

    $form['endpoint']['paths'] = [
      '#type' => 'details',
      '#title' => $this->t('Paths'),
      '#open' => TRUE,
    ];

    $form['endpoint']['paths']['query'] = [
      '#type' => 'textfield',
      '#title' => $this->t('SPARQL query path'),
      '#default_value' => $config->get('endpoint.paths.query') ?? '',
      '#required' => TRUE,
      '#config_target' => 'rdf_sync.settings:endpoint.paths.query',
    ];

    $form['endpoint']['paths']['update'] = [
      '#type' => 'textfield',
      '#title' => $this->t('SPARQL update path'),
      '#default_value' => $config->get('endpoint.paths.update') ?? '',
      '#required' => TRUE,
      '#config_target' => 'rdf_sync.settings:endpoint.paths.update',
    ];

    $form['endpoint']['paths']['graph_store'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Graph store path'),
      '#default_value' => $config->get('endpoint.paths.graph_store') ?? '',
      '#required' => TRUE,
      '#config_target' => 'rdf_sync.settings:endpoint.paths.graph_store',
    ];

    return parent::buildForm($form, $form_state);
  }

}
