<?php

declare(strict_types=1);

namespace Drupal\rdf_sync;

use EasyRdf\Sparql\Result;

/**
 * Provides an interface for the rdf_sync.connection service.
 */
interface RdfSyncConnectionInterface {

  /**
   * Runs a SPARQL query and returns the results.
   *
   * @param string $query
   *   The SPARQL query.
   *
   * @return \EasyRdf\Sparql\Result
   *   The result object.
   */
  public function query(string $query): Result;

  /**
   * Runs a SPARQL update and returns the results.
   *
   * @param string $query
   *   The SPARQL query.
   *
   * @return \EasyRdf\Sparql\Result
   *   The result object.
   */
  public function update(string $query): Result;

  /**
   * Builds the SPARQL endpoint URL.
   *
   * @param string $type
   *   One of 'query', 'update' or 'graph_store'.
   *
   * @return string
   *   The SPARQL endpoint URL.
   */
  public function getEndpointUrl(string $type): string;

}
