<?php

declare(strict_types=1);

namespace Drupal\rdf_sync;

use Drupal\Core\Config\Config;
use Drupal\Core\Config\ConfigFactoryInterface;
use EasyRdf\Graph;
use EasyRdf\GraphStore;
use EasyRdf\Serialiser\Ntriples;

/**
 * Defines rdf_sync.triples service.
 */
class RdfSyncTriples implements RdfSyncTriplesInterface {

  /**
   * The rdf_sync settings.
   *
   * @var \Drupal\Core\Config\Config
   */
  protected Config $config;

  /**
   * Creates Rdf Sync Triples object.
   *
   * @param \Drupal\rdf_sync\RdfSyncConnectionInterface $rdfSyncConnection
   *   Rdf sync connection.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   Config factory.
   */
  public function __construct(
    protected RdfSyncConnectionInterface $rdfSyncConnection,
    ConfigFactoryInterface $configFactory,
  ) {
    $this->config = $configFactory->get('rdf_sync.settings');
  }

  /**
   * {@inheritdoc}
   */
  public function createGraphStore(): GraphStore {
    $connectionString = $this->rdfSyncConnection->getEndpointUrl('graph_store');
    return new GraphStore($connectionString);
  }

  /**
   * {@inheritdoc}
   */
  public function updateTriples(array $triples): void {
    // @todo Replace this with a single query.
    $this->deleteTriples(array_keys($triples));
    $this->insertTriples($triples);
  }

  /**
   * {@inheritdoc}
   *
   * @todo Consider using graph store operations.
   */
  public function deleteTriples(array $uris): void {
    $serializer = new Ntriples();
    $uris = array_map(
      function (string $uri) use ($serializer): string {
        return $serializer->serialiseValue(['value' => $uri, 'type' => 'uri']);
      },
      $uris,
    );

    $graphUri = $this->config->get('graph_uri');
    $uris = implode(",\n", $uris);
    $query = <<<QUERY
        WITH <$graphUri>
        DELETE  { ?subject ?predicate ?object . }
        WHERE {
        ?subject ?predicate ?object .
        FILTER(?subject IN (
        $uris
        )) .
        }
        QUERY;

    $this->rdfSyncConnection->update($query);
  }

  /**
   * {@inheritdoc}
   */
  public function insertTriples(array $triples): void {
    $graph = new Graph();
    $graph->parse($triples, 'php');
    $triples = $graph->serialise('ntriples');
    $graphUri = $this->config->get('graph_uri');
    $query = <<<QUERY
      WITH <$graphUri>
      INSERT {
      $triples
      }
      QUERY;
    $this->rdfSyncConnection->update($query);
  }

}
