<?php

declare(strict_types=1);

namespace Drupal\rdf_sync;

use EasyRdf\GraphStore;

/**
 * Provides an interface for the rdf_sync.triples service.
 */
interface RdfSyncTriplesInterface {

  /**
   * Creates graph store.
   *
   * @return \EasyRdf\GraphStore
   *   Graph store.
   */
  public function createGraphStore(): GraphStore;

  /**
   * Deletes a list of triples from the SPARQL backend given their subjects.
   *
   * @param array $uris
   *   A list of triple URIs to be deleted.
   */
  public function deleteTriples(array $uris): void;

  /**
   * Inserts a list of triples in the SPARQL triple-store.
   *
   * @param array $triples
   *   An array of triples structured as the return of Graph::toRdfPhp().
   *
   * @see \EasyRdf\Graph::toRdfPhp
   */
  public function insertTriples(array $triples): void;

  /**
   * Updates a list of triples in the SPARQL triple-store.
   *
   * @param array $triples
   *   An array of triples structured as the return of Graph::toRdfPhp().
   *
   * @see \EasyRdf\Graph::toRdfPhp
   */
  public function updateTriples(array $triples): void;

}
