<?php

declare(strict_types=1);

namespace Drupal\Tests\rdf_sync\Functional;

use Drupal\Tests\BrowserTestBase;
use Drupal\Tests\rdf_sync\Traits\RdfSyncTestTrait;
use Drush\TestTraits\DrushTestTrait;

/**
 * @coversDefaultClass \Drupal\rdf_sync\Drush\Commands\RdfSyncCommands
 *
 * @group rdf_sync
 */
class RdfSyncDrushTest extends BrowserTestBase {

  use DrushTestTrait;
  use RdfSyncTestTrait;

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'rdf_sync',
    'rdf_sync_test',
    'taxonomy',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->setUpFields();
  }

  /**
   * @covers ::enableSynchronization
   * @covers ::disableSynchronization
   * @covers ::synchronize
   */
  public function testCommands(): void {
    $this->drush('config:set', ['rdf_sync.settings', 'endpoint.host', 'virtuoso']);

    $this->drush('rdf_sync:enable');
    $this->assertFalse(\Drupal::keyValue('state')->has('rdf_sync.synchronization_disabled'));

    $this->drush('rdf_sync:disable');
    $this->assertTrue(\Drupal::state()->get('rdf_sync.synchronization_disabled'));

    [$term, $node] = $this->createEntities();

    $this->drush('rdf_sync:synchronize', ['taxonomy_term']);
    $this->assertTriples('http://data', [
      '<http://example.com/category/id/1> <http://www.w3.org/2004/02/skos/core#inScheme> <http://example.com/category>',
      '<http://example.com/category/id/1> <http://www.w3.org/2004/02/skos/core#prefLabel> "Series"@en',
      '<http://example.com/category/id/1> <http://www.w3.org/2004/02/skos/core#definition> "7 seasons"@en',
      '<http://example.com/category/id/1> <http://www.w3.org/2004/02/skos/core#broaderTransitive> <http://example.com/category/parent/1>',
      '<http://example.com/category/id/1> <http://www.w3.org/2004/02/skos/core#broaderTransitive> <http://example.com/category/parent/2>',
      '<http://example.com/category/id/1> <http://www.w3.org/1999/02/22-rdf-syntax-ns#type> <http://www.w3.org/2004/02/skos/core#Concept>',
    ]);
    $this->drush('rdf_sync:synchronize', ['node']);
    $this->assertTriples('http://data', [
      '<http://example.com/page/id/1> <http://www.w3.org/1999/02/22-rdf-syntax-ns#type> <http://example.com/page>',
      '<http://example.com/page/id/1> <http://example.com/page/title> "Mad Men"@en',
      '<http://example.com/page/id/1> <http://example.com/page/category> <http://example.com/category/id/1>',
      '<http://example.com/page/id/1> <http://example.com/page/body> "Strong is stripped while <em>Emphasis</em> is kept"@en',
    ]);

    $this->drush('rdf_sync:enable');
    $node->delete();
    $term->delete();

    $this->assertNoTriples('http://data', [
      '<http://example.com/category/id/1> <http://www.w3.org/2004/02/skos/core#inScheme> <http://example.com/category>',
      '<http://example.com/category/id/1> <http://www.w3.org/2004/02/skos/core#prefLabel> "Series"@en',
      '<http://example.com/category/id/1> <http://www.w3.org/2004/02/skos/core#definition> "7 seasons"@en',
      '<http://example.com/category/id/1> <http://www.w3.org/1999/02/22-rdf-syntax-ns#type> <http://www.w3.org/2004/02/skos/core#Concept>',
      '<http://example.com/category/id/1> <http://www.w3.org/2004/02/skos/core#broaderTransitive> <http://example.com/category/parent/1>',
      '<http://example.com/category/id/1> <http://www.w3.org/2004/02/skos/core#broaderTransitive> <http://example.com/category/parent/2>',
      '<http://example.com/page/id/1> <http://www.w3.org/1999/02/22-rdf-syntax-ns#type> <http://example.com/page>',
      '<http://example.com/page/id/1> <http://example.com/page/title> "Mad Men"@en',
      '<http://example.com/page/id/1> <http://example.com/page/category> <http://example.com/category/id/1>',
      '<http://example.com/page/id/1> <http://example.com/page/body> "Strong is stripped while <em>Emphasis</em> is kept"@en',
    ]);
  }

}
